==> user_referral-2.0.1.tar.gz: user_referral/src/Tests/Functional/UserReferralUserRegisterTest.php <==
<?php

namespace Drupal\user_referral\Tests\Functional;

use Drupal\user\Entity\User;
use Drupal\Tests\user_referral\Traits\UserReferralTypeTestTrait;
use Drupal\Tests\user_referral\Traits\UserRegistrationTrait;
use Drupal\user_referral\Entity\UserReferralType;
use Drupal\Tests\BrowserTestBase;
use Drupal\user_referral\UserReferral;
use Drupal\Core\Entity\Entity\EntityFormDisplay;
use Drupal\Core\Entity\Entity\EntityViewDisplay;
use Drupal\Core\Entity\Entity\EntityViewMode;

/**
 * Test basic functionality of user_referral module.
 *
 * @group user_referral
 */
class UserReferralUserRegisterTest extends BrowserTestBase {

  use UserReferralTypeTestTrait {
    createUserReferralType as drupalCreateUserReferralType;
  }

  use UserRegistrationTrait;

  protected $defaultTheme = 'stark';

  /**
   * {@inheritdoc}
   */
  public static $modules = [
    'user_referral',
  ];

  /**
   * {@inheritdoc}
   */
  protected function setUp() {
    parent::setUp();

    $permissions = [
      'access administration pages',
      'administer modules',
      'administer site configuration',
      'administer users',
      'administer user referral types',
      'change any user referral',
    ];

    $this->consultant_role = $this->drupalCreateRole([], 'consultant');
    $this->referral_partner_role = $this->drupalCreateRole([], 'referral partner');

    $this->consultant_referral_type = $this->drupalCreateUserReferralType([
      'type' => 'consultant',
      'name' => 'Consultant',
      'referral_field' => 'field_referral_id',
      'roles' => ['consultant'],
      'url_alias_pattern' => '/[user_referral_type:referral_field_value]',
      'reset_cookie_lifetime_for_same_referrer' => TRUE,
      'change_referrer_in_cookie' => TRUE,
    ]);

    $this->referral_partner_referral_type = $this->drupalCreateUserReferralType([
      'type' => 'referralpartner',
      'name' => 'Referral Partner',
      'referral_field' => 'field_referral_id',
      'roles' => ['referral partner'],
      'url_alias_pattern' => '/[user_referral_type:referral_field_value]/[user_referral_type:type]',
      'reset_cookie_lifetime_for_same_referrer' => TRUE,
      'change_referrer_in_cookie' => TRUE,
    ]);

    $this->consultant_referrer_1 = $this->drupalCreateUser([], 'creferrer1', FALSE, ['field_referral_id' => 'creferrer1', 'roles' => ['consultant']]);
    $this->consultant_referrer_2 = $this->drupalCreateUser([], 'creferrer2', FALSE, ['field_referral_id' => 'creferrer2', 'roles' => ['consultant']]);
    $this->referral_partner_referrer = $this->drupalCreateUser([], 'rpreferrer2', FALSE, ['field_referral_id' => 'rpreferrer2', 'roles' => ['referral partner']]);
    
    // Ensure referral link aliases are created.
    $this->consultant_referral_type->getReferralLink($this->consultant_referrer_1);
    $this->consultant_referral_type->getReferralLink($this->consultant_referrer_2);
    $this->referral_partner_referral_type->getReferralLink($this->referral_partner_referrer);

    // User to set up realname.
    $this->admin_user = $this->drupalCreateUser($permissions);

    // Create form display with the user_referrer field.
    $form_display = EntityFormDisplay::create([
      'targetEntityType' => 'user',
      'bundle' => 'user',
      'mode' => 'default',
      'status' => TRUE,
    ]);
    $form_display->setComponent('user_referrer');
    $form_display->save();

    // EntityViewMode::create([
    //   'id' => 'user.default',
    //   'targetEntityType' => 'user',
    //   'status' => TRUE,
    //   'enabled' => TRUE,
    //   'label' => $this->randomMachineName(),
    // ])->save();
    // EntityViewDisplay::create([
    //   'targetEntityType' => 'user',
    //   'bundle' => 'user',
    //   'mode' => 'default',
    //   'status' => TRUE,
    // ])
    //   ->setComponent('user_referral', [
    //     'settings' => [
    //       'label_display' => 'inline',
    //       'label' => 'Referrer',
    //       'value' => '[user:name] ([user_referral_type:name])',
    //     ],
    //     'third_party_settings' => [],
    //     'weight' => 1,
    //     'region' => 'content',
    //   ])
    //   ->save();
  }

  /**
   * Test realname configuration.
   */
  public function testUserRegistrations() {
    // Test with direct referral link
    $this->drupalGet('user/' . $this->consultant_referrer_1->id() . '/user-referral/' . $this->consultant_referral_type->id());
    $this->assertSession()->statusCodeEquals(200);
    $last_user = $this->registerUser();
    $this->assertSession()->statusCodeEquals(200);
    $referrer = UserReferral::getReferrer($last_user);
    $this->assertEqual($this->consultant_referrer_1->id(), $referrer->id(), t('Referrer got recorded'));
    $referral_entry = UserReferral::getReferralEntry($last_user);
    $this->assertNotIdentical(FALSE, $referral_entry, t('Referral entry exists'));
    $this->assertEqual($this->consultant_referrer_1->id(), $referral_entry->referrer_uid, t('Referrer got recorded'));
    $this->assertEqual($this->consultant_referral_type->id(), $referral_entry->type, t('Referral type matches in referral entry'));
    $this->assertEqual(0, $referral_entry->manually_entered, t('Referral entry is not manually entered.'));

    $old_referral_entry = clone $referral_entry;
    $this->drupalLogin($this->admin_user);
    $edit = [];
    $edit['user_referrer[referrer]'] = $this->consultant_referrer_2->label() . ' (' . $this->consultant_referrer_2->id() . ')';
    $this->drupalPostForm('user/' . $last_user->id() . '/edit', $edit, t('Save'));
    $referral_entry = UserReferral::getReferralEntry($last_user);
    $this->assertNotIdentical(FALSE, $referral_entry, t('Referral entry exists'));
    $this->assertNotEqual($old_referral_entry->id, $referral_entry->id, t('Active referrer entry got changed'));
    $this->assertEqual($this->consultant_referrer_2->id(), $referral_entry->referrer_uid, t('Referrer got recorded'));
    $this->assertEqual($this->consultant_referral_type->id(), $referral_entry->type, t('Referral type matches in referral entry'));
    $this->assertEqual(1, $referral_entry->manually_entered, t('Referral entry is not manually entered.'));
    $this->drupalLogout();

    $this->getSession()->reset(); // Reset browser session cookie re-assining logic wont affect.

    // Test with referral link alias.
    $this->drupalGet($this->referral_partner_referrer->field_referral_id->value . '/' . $this->referral_partner_referral_type->id());
    $this->assertSession()->statusCodeEquals(200);
    $last_user = $this->registerUser();
    $this->assertSession()->statusCodeEquals(200);
    $referrer = UserReferral::getReferrer($last_user);
    $this->assertEqual($this->referral_partner_referrer->id(), $referrer->id(), t('Referrer got recorded'));
    $referral_entry = UserReferral::getReferralEntry($last_user);
    $this->assertNotIdentical(FALSE, $referral_entry, t('Referral entry exists'));
    $this->assertEqual($this->referral_partner_referrer->id(), $referral_entry->referrer_uid, t('Referrer got recorded'));
    $this->assertEqual($this->referral_partner_referral_type->id(), $referral_entry->type, t('Referral type matches in referral entry'));
    $this->assertEqual(0, $referral_entry->manually_entered, t('Referral entry is not manually entered.'));

    $this->drupalLogin($this->admin_user);
    $edit = [];
    $edit['user_referrer[referrer]'] = $this->consultant_referrer_1->label() . ' (' . $this->consultant_referrer_1->id() . ')';
    $this->drupalPostForm('user/' . $last_user->id() . '/edit', $edit, t('Save'));
    $referral_entry = UserReferral::getReferralEntry($last_user);
    $this->assertNotIdentical(FALSE, $referral_entry, t('Referral entry exists'));
    $this->assertEqual($this->consultant_referrer_1->id(), $referral_entry->referrer_uid, t('Referrer got recorded'));
    $this->assertEqual($this->consultant_referral_type->id(), $referral_entry->type, t('Referral type matches in referral entry'));
    $this->assertEqual(1, $referral_entry->manually_entered, t('Referral entry is not manually entered.'));
    // $this->drupalGet('user/' . $this->consultant_referrer_1->id());
    // $this->assertSession()->pageTextContains($this->consultant_referrer_1->label() . '(' . $this->consultant_referral_type->label() . ')');
    $this->drupalLogout();
  }

}

==> user_referral-2.0.4.tar.gz: user_referral/src/Tests/Functional/UserReferralUserRegisterTest.php <==
<?php

namespace Drupal\user_referral\Tests\Functional;

use Drupal\user\Entity\User;
use Drupal\Tests\user_referral\Traits\UserReferralTypeTestTrait;
use Drupal\Tests\user_referral\Traits\UserRegistrationTrait;
use Drupal\user_referral\Entity\UserReferralType;
use Drupal\Tests\BrowserTestBase;
use Drupal\user_referral\UserReferral;
use Drupal\Core\Entity\Entity\EntityFormDisplay;
use Drupal\Core\Entity\Entity\EntityViewDisplay;
use Drupal\Core\Entity\Entity\EntityViewMode;

/**
 * Test basic functionality of user_referral module.
 *
 * @group user_referral
 */
class UserReferralUserRegisterTest extends BrowserTestBase {

  use UserReferralTypeTestTrait {
    createUserReferralType as drupalCreateUserReferralType;
  }

  use UserRegistrationTrait;

  protected $defaultTheme = 'stark';

  /**
   * {@inheritdoc}
   */
  public static $modules = [
    'user_referral',
  ];

  /**
   * {@inheritdoc}
   */
  protected function setUp() {
    parent::setUp();

    $permissions = [
      'access administration pages',
      'administer modules',
      'administer site configuration',
      'administer users',
      'administer user referral types',
      'change any user referral',
    ];

    $this->consultant_role = $this->drupalCreateRole([], 'consultant');
    $this->referral_partner_role = $this->drupalCreateRole([], 'referral partner');

    $this->consultant_referral_type = $this->drupalCreateUserReferralType([
      'type' => 'consultant',
      'name' => 'Consultant',
      'referral_field' => 'field_referral_id',
      'roles' => ['consultant'],
      'url_alias_pattern' => '/[user_referral_type:referral_field_value]',
      'reset_cookie_lifetime_for_same_referrer' => TRUE,
      'change_referrer_in_cookie' => TRUE,
    ]);

    $this->referral_partner_referral_type = $this->drupalCreateUserReferralType([
      'type' => 'referralpartner',
      'name' => 'Referral Partner',
      'referral_field' => 'field_referral_id',
      'roles' => ['referral partner'],
      'url_alias_pattern' => '/[user_referral_type:referral_field_value]/[user_referral_type:type]',
      'reset_cookie_lifetime_for_same_referrer' => TRUE,
      'change_referrer_in_cookie' => TRUE,
    ]);

    $this->consultant_referrer_1 = $this->drupalCreateUser([], 'creferrer1', FALSE, ['field_referral_id' => 'creferrer1', 'roles' => ['consultant']]);
    $this->consultant_referrer_2 = $this->drupalCreateUser([], 'creferrer2', FALSE, ['field_referral_id' => 'creferrer2', 'roles' => ['consultant']]);
    $this->referral_partner_referrer = $this->drupalCreateUser([], 'rpreferrer2', FALSE, ['field_referral_id' => 'rpreferrer2', 'roles' => ['referral partner']]);

    // Ensure referral link aliases are created.
    $this->consultant_referral_type->getReferralLink($this->consultant_referrer_1);
    $this->consultant_referral_type->getReferralLink($this->consultant_referrer_2);
    $this->referral_partner_referral_type->getReferralLink($this->referral_partner_referrer);

    // User to set up realname.
    $this->admin_user = $this->drupalCreateUser($permissions);

    // Create form display with the user_referrer field.
    $form_display = EntityFormDisplay::create([
      'targetEntityType' => 'user',
      'bundle' => 'user',
      'mode' => 'default',
      'status' => TRUE,
    ]);
    $form_display->setComponent('user_referrer');
    $form_display->save();

    // EntityViewMode::create([
    //   'id' => 'user.default',
    //   'targetEntityType' => 'user',
    //   'status' => TRUE,
    //   'enabled' => TRUE,
    //   'label' => $this->randomMachineName(),
    // ])->save();
    // EntityViewDisplay::create([
    //   'targetEntityType' => 'user',
    //   'bundle' => 'user',
    //   'mode' => 'default',
    //   'status' => TRUE,
    // ])
    //   ->setComponent('user_referral', [
    //     'settings' => [
    //       'label_display' => 'inline',
    //       'label' => 'Referrer',
    //       'value' => '[user:name] ([user_referral_type:name])',
    //     ],
    //     'third_party_settings' => [],
    //     'weight' => 1,
    //     'region' => 'content',
    //   ])
    //   ->save();
  }

  /**
   * Test realname configuration.
   */
  public function testUserRegistrations() {
    // Test with direct referral link
    $this->drupalGet('user/' . $this->consultant_referrer_1->id() . '/user-referral/' . $this->consultant_referral_type->id());
    $this->assertSession()->statusCodeEquals(200);
    $last_user = $this->registerUser();
    $this->assertSession()->statusCodeEquals(200);
    $referrer = UserReferral::getReferrer($last_user);
    $this->assertEquals($this->consultant_referrer_1->id(), $referrer->id(), t('Referrer got recorded'));
    $referral_entry = UserReferral::getReferralEntry($last_user);
    $this->assertNotSame(FALSE, $referral_entry, t('Referral entry exists'));
    $this->assertEquals($this->consultant_referrer_1->id(), $referral_entry->referrer_uid, t('Referrer got recorded'));
    $this->assertEquals($this->consultant_referral_type->id(), $referral_entry->type, t('Referral type matches in referral entry'));
    $this->assertEquals(0, $referral_entry->manually_entered, t('Referral entry is not manually entered.'));

    $old_referral_entry = clone $referral_entry;
    $this->drupalLogin($this->admin_user);
    $edit = [];
    $edit['user_referrer[referrer]'] = $this->consultant_referrer_2->label() . ' (' . $this->consultant_referrer_2->id() . ')';
    $this->drupalGet('user/' . $last_user->id() . '/edit');
    $this->submitForm($edit, t('Save'));
    $referral_entry = UserReferral::getReferralEntry($last_user);
    $this->assertNotSame(FALSE, $referral_entry, t('Referral entry exists'));
    $this->assertNotEquals($old_referral_entry->id, $referral_entry->id, t('Active referrer entry got changed'));
    $this->assertEquals($this->consultant_referrer_2->id(), $referral_entry->referrer_uid, t('Referrer got recorded'));
    $this->assertEquals($this->consultant_referral_type->id(), $referral_entry->type, t('Referral type matches in referral entry'));
    $this->assertEquals(1, $referral_entry->manually_entered, t('Referral entry is not manually entered.'));
    $this->drupalLogout();

    $this->getSession()->reset(); // Reset browser session cookie re-assining logic wont affect.

    // Test with referral link alias.
    $this->drupalGet($this->referral_partner_referrer->field_referral_id->value . '/' . $this->referral_partner_referral_type->id());
    $this->assertSession()->statusCodeEquals(200);
    $last_user = $this->registerUser();
    $this->assertSession()->statusCodeEquals(200);
    $referrer = UserReferral::getReferrer($last_user);
    $this->assertEquals($this->referral_partner_referrer->id(), $referrer->id(), t('Referrer got recorded'));
    $referral_entry = UserReferral::getReferralEntry($last_user);
    $this->assertNotSame(FALSE, $referral_entry, t('Referral entry exists'));
    $this->assertEquals($this->referral_partner_referrer->id(), $referral_entry->referrer_uid, t('Referrer got recorded'));
    $this->assertEquals($this->referral_partner_referral_type->id(), $referral_entry->type, t('Referral type matches in referral entry'));
    $this->assertEquals(0, $referral_entry->manually_entered, t('Referral entry is not manually entered.'));

    $this->drupalLogin($this->admin_user);
    $edit = [];
    $edit['user_referrer[referrer]'] = $this->consultant_referrer_1->label() . ' (' . $this->consultant_referrer_1->id() . ')';
    $this->drupalGet('user/' . $last_user->id() . '/edit');
    $this->submitForm($edit, t('Save'));
    $referral_entry = UserReferral::getReferralEntry($last_user);
    $this->assertNotSame(FALSE, $referral_entry, t('Referral entry exists'));
    $this->assertEquals($this->consultant_referrer_1->id(), $referral_entry->referrer_uid, t('Referrer got recorded'));
    $this->assertEquals($this->consultant_referral_type->id(), $referral_entry->type, t('Referral type matches in referral entry'));
    $this->assertEquals(1, $referral_entry->manually_entered, t('Referral entry is not manually entered.'));
    // $this->drupalGet('user/' . $this->consultant_referrer_1->id());
    // $this->assertSession()->pageTextContains($this->consultant_referrer_1->label() . '(' . $this->consultant_referral_type->label() . ')');
    $this->drupalLogout();
  }

}
